==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkBlankStructuredGrid.java <==
// java wrapper for vtkBlankStructuredGrid object
//

package vtk;
import vtk.*;

public class vtkBlankStructuredGrid extends vtkStructuredGridAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetMinBlankingValue_2(double id0);
  public void SetMinBlankingValue(double id0)
    { SetMinBlankingValue_2(id0); }

  private native double GetMinBlankingValue_3();
  public double GetMinBlankingValue()
    { return GetMinBlankingValue_3(); }

  private native void SetMaxBlankingValue_4(double id0);
  public void SetMaxBlankingValue(double id0)
    { SetMaxBlankingValue_4(id0); }

  private native double GetMaxBlankingValue_5();
  public double GetMaxBlankingValue()
    { return GetMaxBlankingValue_5(); }

  private native void SetArrayName_6(String id0);
  public void SetArrayName(String id0)
    { SetArrayName_6(id0); }

  private native String GetArrayName_7();
  public String GetArrayName()
    { return GetArrayName_7(); }

  private native void SetArrayId_8(int id0);
  public void SetArrayId(int id0)
    { SetArrayId_8(id0); }

  private native int GetArrayId_9();
  public int GetArrayId()
    { return GetArrayId_9(); }

  private native void SetComponent_10(int id0);
  public void SetComponent(int id0)
    { SetComponent_10(id0); }

  private native int GetComponentMinValue_11();
  public int GetComponentMinValue()
    { return GetComponentMinValue_11(); }

  private native int GetComponentMaxValue_12();
  public int GetComponentMaxValue()
    { return GetComponentMaxValue_12(); }

  private native int GetComponent_13();
  public int GetComponent()
    { return GetComponent_13(); }

  public vtkBlankStructuredGrid() { super(); }

  public vtkBlankStructuredGrid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-19-aarch64.pkg.tar.xz: vtk/vtkBlankStructuredGrid.java <==
// java wrapper for vtkBlankStructuredGrid object
//

package vtk;
import vtk.*;

public class vtkBlankStructuredGrid extends vtkStructuredGridAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetMinBlankingValue_2(double id0);
  public void SetMinBlankingValue(double id0)
    { SetMinBlankingValue_2(id0); }

  private native double GetMinBlankingValue_3();
  public double GetMinBlankingValue()
    { return GetMinBlankingValue_3(); }

  private native void SetMaxBlankingValue_4(double id0);
  public void SetMaxBlankingValue(double id0)
    { SetMaxBlankingValue_4(id0); }

  private native double GetMaxBlankingValue_5();
  public double GetMaxBlankingValue()
    { return GetMaxBlankingValue_5(); }

  private native void SetArrayName_6(String id0);
  public void SetArrayName(String id0)
    { SetArrayName_6(id0); }

  private native String GetArrayName_7();
  public String GetArrayName()
    { return GetArrayName_7(); }

  private native void SetArrayId_8(int id0);
  public void SetArrayId(int id0)
    { SetArrayId_8(id0); }

  private native int GetArrayId_9();
  public int GetArrayId()
    { return GetArrayId_9(); }

  private native void SetComponent_10(int id0);
  public void SetComponent(int id0)
    { SetComponent_10(id0); }

  private native int GetComponentMinValue_11();
  public int GetComponentMinValue()
    { return GetComponentMinValue_11(); }

  private native int GetComponentMaxValue_12();
  public int GetComponentMaxValue()
    { return GetComponentMaxValue_12(); }

  private native int GetComponent_13();
  public int GetComponent()
    { return GetComponent_13(); }

  public vtkBlankStructuredGrid() { super(); }

  public vtkBlankStructuredGrid(long id) { super(id); }
  public native long   VTKInit();

}
